"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class SimpleCache {
    constructor(ttl) {
        this.data = {};
        this.ttl = ttl;
        this.checkInterval = setInterval(() => this.checkAllTtl(), 1000);
    }
    get(key) {
        return this.data[key]?.value;
    }
    set(key, value, customTtl) {
        const now = Date.now();
        const ttl = now + (customTtl ?? this.ttl);
        this.data[key] = { value, ttl };
        return value;
    }
    has(key) {
        if (typeof this.data[key] === 'undefined') {
            return false;
        }
        return true;
    }
    async getOrSet(key, value, customTtl) {
        const get = this.get(key);
        if (get) {
            return get;
        }
        if (typeof value !== 'function') {
            return this.set(key, value, customTtl);
        }
        if (typeof value() === 'object' && typeof value().then === 'function') {
            return this.set(key, await value(), customTtl);
        }
        return this.set(key, value(), customTtl);
    }
    delete(key) {
        delete this.data[key];
    }
    checkTtl(key) {
        if (this.data[key]?.ttl < Date.now()) {
            this.delete(key);
            return false;
        }
        return true;
    }
    checkAllTtl() {
        Object.keys(this.data).forEach((key) => this.checkTtl(key));
    }
    clearCheckTtl() {
        clearInterval(this.checkInterval);
    }
}
exports.default = SimpleCache;
//# sourceMappingURL=index.js.map